@@ -26,11 +26,11 @@ extern int FLAGS;
 extern int THREADS;
 
 /**
- * The ::RANDOM_ANCHOR_PROP represents the probability with which a found
- * anchor is a random match and not homologous. Its value can be set using
- * the `-p` switch.
+ * The ::ANCHOR_P_VALUE represents the probability that an anchor will be found,
+ * if the two sequences are unrelated. I.e. it is the p-value for H_0: random
+ * sequences. Its value can be set using the `-p` switch.
  */
-extern double RANDOM_ANCHOR_PROP;
+extern double ANCHOR_P_VALUE;
 
 /**
  * The number of matrices that should be bootstrapped.
@@ -49,11 +49,6 @@ extern int MODEL;
 
 enum { M_RAW, M_JC, M_KIMURA };
 
-/**
- * Global exit code. Should be non-zero on error.
- */
-extern int EXIT_CODE;
-
 /**
  * This enum contains the available flags. Please note that all
  * available options are a power of 2.
@@ -66,7 +61,9 @@ enum {
 	F_NON_ACGT = 8,
 	F_JOIN = 16,
 	F_LOW_MEMORY = 32,
-	F_SHORT = 64
+	F_SHORT = 64,
+	F_PRINT_PROGRESS = 128,
+	F_SOFT_ERROR = 256
 };
 
 /**
@@ -79,6 +76,26 @@ enum {
 		if (PTR == NULL) {                                                     \
 			err(errno, "Out of memory");                                       \
 		}                                                                      \
-	} while (0);
+	} while (0)
+
+/**
+ * @brief This macro is used to print a warning and make the program exit with
+ * an failure exit code, later.
+ */
+#define soft_err(...)                                                          \
+	do {                                                                       \
+		FLAGS |= F_SOFT_ERROR;                                                 \
+		warn(__VA_ARGS__);                                                     \
+	} while (0)
+
+/**
+ * @brief This macro is used to print a warning and make the program exit with
+ * an failure exit code, later.
+ */
+#define soft_errx(...)                                                         \
+	do {                                                                       \
+		FLAGS |= F_SOFT_ERROR;                                                 \
+		warnx(__VA_ARGS__);                                                    \
+	} while (0)
 
 #endif
