@@ -12,5 +12,15 @@
 ./src/andi test_extra.fasta --low-memory > extra_low_memory.out
 diff extra.out extra_low_memory.out || exit 1
 
-rm -f test_extra.fasta extra.out extra_low_memory.out
+# Test file of filenames
+./test/test_fasta -l 10000 > test_extra.fasta
+echo "$PWD/test_extra.fasta" > fof.txt
+./src/andi test_extra.fasta > extra.out
+./src/andi --file-of-filenames fof.txt > fof.out
+cat fof.txt | ./src/andi --file-of-filenames - > fof2.out
+diff extra.out fof.out || exit 1
+diff extra.out fof2.out || exit 1
+
+
+rm -f test_extra.fasta extra.out extra_low_memory.out fof.out fof2.out fof.txt
 
